@@ -33,7 +33,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 use warnings;
 use Carp;
@@ -140,11 +140,13 @@ our %field_conf = (
     type => 'ARRAY',
     process => sub {
       my $val = shift;
-      if ($val =~ /^"(.+?)"\s*(.*)/) {
+      if ($val =~ /^"(.+?[^\\])"\s*(.*)/) {
         my $synonym = $1;
         my @dbxrefs = ();
         my $rest = $2;
 
+        $synonym =~ s/\\(.)/$1/g;
+
         my %ret = (
           synonym => $synonym,
         );
