@@ -36,7 +36,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 use Mouse;
 use FileHandle;
@@ -110,7 +110,7 @@ sub _finish_stanza
       } @{$current->{synonym}}
     ];
 
-    $current->{synonym} = [values %seen_synonyms];
+    $current->{synonym} = [sort { $a->{synonym} cmp $b->{synonym} } values %seen_synonyms];
   }
 
   my $options = { namespace_from_metadata => $namespace_from_metadata };
